__requires__ = [
    'wheel',
    'pip-run',
    'setuptools_scm',
    'build',
    'git-fame',
    'jaraco.context',
    'requests',
    'packaging',
    'jaraco.functools',
    'python-dateutil',
    'jaraco.compat >= 4.1',
]


from .backend import (
    build_sdist,
    prepare_metadata,
    build_wheel,
    build_editable,
)

prepare_metadata_for_build_wheel = prepare_metadata_for_build_editable = (
    prepare_metadata
)


__all__ = [
    'build_sdist',
    'prepare_metadata_for_build_wheel',
    'prepare_metadata_for_build_editable',
    'build_wheel',
    'build_editable',
]



import contextlib
import importlib.resources
import pathlib


@contextlib.contextmanager
def write_pyproject():
    path = pathlib.Path('pyproject.toml')
    if path.exists():
        yield
        return
    path.write_text(importlib.resources.files().joinpath('system.toml').read_text())
    try:
        yield
    finally:
        path.unlink()
